Example Applications — Personis 12.9 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Personis 12.9 documentation »

# Example Applications

## Museum Guide

## Health Monitoring

## Drill and Practice

### Table Of Contents

- Example Applications
  - Museum Guide
  - Health Monitoring
  - Drill and Practice

#### Previous topic

Personis Server

#### Next topic

Application Program Interface

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- modules |
- next |
- previous |
- Personis 12.9 documentation »

© Copyright 2011-2012, Bob Kummerfeld and Judy Kay. Created using Sphinx 1.1.3.